@@ -178,7 +178,12 @@ class NVD3Chart:
                 "size": csize[i] if isinstance(csize, list) else csize
             } for i, y in enumerate(y)]
         else:
-            serie = [{"x": x[i], "y": y} for i, y in enumerate(y)]
+            if self.model == 'pieChart':
+                serie = [{"label": x[i], "value": y} for i, y in enumerate(y)]
+            elif self.model == 'linePlusBarWithFocusChart':
+                serie = [[x[i], y] for i, y in enumerate(y)]
+            else:
+                serie = [{"x": x[i], "y": y} for i, y in enumerate(y)]
 
         data_keyvalue = {"values": serie, "key": name}
 
@@ -196,7 +201,8 @@ class NVD3Chart:
         if 'yaxis' in kwargs and kwargs["yaxis"]:
             data_keyvalue["yAxis"] = kwargs["yaxis"]
         else:
-            data_keyvalue["yAxis"] = "1"
+            if self.model != 'pieChart' and self.model != 'linePlusBarWithFocusChart':
+                data_keyvalue["yAxis"] = "1"
 
         if 'bar' in kwargs and kwargs["bar"]:
             data_keyvalue["bar"] = 'true'
@@ -219,7 +225,7 @@ class NVD3Chart:
                 _start = ("'" + str(_start) + "' + ") if _start else ''
                 _end = (" + '" + str(_end) + "'") if _end else ''
 
-                if self.model == 'linePlusBarChart':
+                if self.model == 'linePlusBarChart' or self.model == 'linePlusBarWithFocusChart':
                     self.tooltip_condition_string += stab(3) + "if(key.indexOf('" + name + "') > -1 ){\n" +\
                         stab(4) + "var y = " + _start + " String(graph.point.y) " + _end + ";\n" +\
                         stab(3) + "}\n"
@@ -238,7 +244,7 @@ class NVD3Chart:
                 _start = ("'" + str(_start) + "' + ") if _start else ''
                 _end = (" + '" + str(_end) + "'") if _end else ''
                 self.tooltip_condition_string += \
-                    "var y = " + _start + " String(e.point.y) " + _end + ";\n"
+                    "var y = " + _start + " String(y) " + _end + ";\n"
 
         self.series.append(data_keyvalue)
 
@@ -384,9 +390,10 @@ class NVD3Chart:
         if self.height:
             self.d3_select_extra += ".attr('height', %s)\n" % self.height
 
-        datum = "data_%s" % self.name
         if self.model == 'pieChart':
-            datum = "[data_%s[0].values]" % self.name
+            datum = "data_%s[0].values" % self.name
+        else:
+            datum = "data_%s" % self.name
 
         # add custom tooltip string in jschart
         # default condition (if build_custom_tooltip is not called explicitly with date_flag=True)
@@ -425,20 +432,31 @@ class NVD3Chart:
 
         #Include data
         series_js = json.dumps(self.series)
-        self.jschart += """data_%s=%s;\n""" % (self.name, series_js)
+
+        if self.model == 'linePlusBarWithFocusChart':
+            append_to_data = ".map(function(series) {"+\
+                "series.values = series.values.map(function(d) { return {x: d[0], y: d[1] } });"+\
+                "return series; })"
+            self.jschart += """data_%s=%s%s;\n""" % (self.name, series_js, append_to_data)
+        else:
+            self.jschart += """data_%s=%s;\n""" % (self.name, series_js)
+
         if self.tag_script_js:
             self.jschart += "</script>"
 
-    def create_x_axis(self, name, label=None, format=None, date=False):
+    def create_x_axis(self, name, label=None, format=None, date=False, custom_format=False):
         """
         Create X-axis
         """
         axis = {}
-        if format:
-            if format == 'AM_PM':
-                axis["tickFormat"] = "function(d) { return get_am_pm(parseInt(d)); }"
-            else:
-                axis["tickFormat"] = "d3.format(',%s')" % format
+        if custom_format and format:
+            axis["tickFormat"] = format
+        else:
+            if format:
+                if format == 'AM_PM':
+                    axis["tickFormat"] = "function(d) { return get_am_pm(parseInt(d)); }"
+                else:
+                    axis["tickFormat"] = "d3.format(',%s')" % format
 
         if label:
             axis["axisLabel"] = label
